How to
======

How to:

.. toctree::
   :maxdepth: 1

   install-nashpy.rst
   create-a-game.rst
   calculate-utilities.rst
   check-best-responses.rst
   solve-with-support-enumeration.rst
   solve-with-vertex-enumeration.rst
   solve-with-lemke-howson.rst
   use-fictitious-play.rst
   use-stochastic-fictitious-play.rst
   use-replicator-dynamics.rst
   use-replicator-dynamics-with-mutation.rst
   use-asymmetric-replicator-dynamics.rst
   use-moran-processes.rst
   obtain-fixation-probabilities.rst
   obtain-a-repeated-game.rst
   use-moran-process-on-replacement-graph.rst
   use-moran-process-on-interaction-graph.rst
